@@ -5,10 +5,17 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-08-19'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem directory name on a Unix system',
+    description => <<'MARKDOWN',
+
+This is like the `dirname` schema but with extra checks relevant to the Unix,
+(e.g. a path element cannot be longer than 255 characters) and prefilters (e.g.
+multipile consecutive slashes `//` will be normalized into a single one `/`).
+
+MARKDOWN
     match => '\A(?:/|/?(?:[^/\0]{1,255})(?:/[^/\0]{1,255})*)\z',
     'x.completion' => ['dirname'],
     prefilters => [
@@ -42,7 +49,7 @@ Sah::Schema::dirname::unix - Filesystem directory name on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.019 of Sah::Schema::dirname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.020 of Sah::Schema::dirname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
 
 =head1 SYNOPSIS
 
@@ -80,7 +87,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "foo\0";
+ $data = "";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -95,8 +102,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # => ["","foo/bar"]
  
  # a sample invalid data
- $data = "foo\0";
- my $res = $validator->($data); # => ["Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z","foo\0"]
+ $data = "";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z",""]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -189,6 +196,12 @@ L<Type::Tiny> as well as L<Type::FromSah>):
  use My::Types qw(DirnameUnix);
  DirnameUnix->assert_valid($data);
 
+=head1 DESCRIPTION
+
+This is like the C<dirname> schema but with extra checks relevant to the Unix,
+(e.g. a path element cannot be longer than 255 characters) and prefilters (e.g.
+multipile consecutive slashes C<//> will be normalized into a single one C</>).
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Path>.
