@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-08-19'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem file name',
@@ -23,8 +23,7 @@ longer than 255 characters) and preprocessing (e.g. stripping extraneous slashes
 like `foo//bar` into `foo/bar`.
 
 What's the difference between this schema and `dirname`? The default completion
-rule. This schema's completion by default only includes files and not
-directories.
+rule. `dirname`'s completion only includes directories and not files.
 
 _
 
@@ -59,7 +58,7 @@ Sah::Schema::filename - Filesystem file name
 
 =head1 VERSION
 
-This document describes version 0.019 of Sah::Schema::filename (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.020 of Sah::Schema::filename (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
 
 =head1 SYNOPSIS
 
@@ -87,7 +86,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo";
+ $data = "foo/bar";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -102,8 +101,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo";
- my $res = $validator->($data); # => ["","foo"]
+ $data = "foo/bar";
+ my $res = $validator->($data); # => ["","foo/bar"]
  
  # a sample invalid data
  $data = "";
@@ -214,8 +213,7 @@ longer than 255 characters) and preprocessing (e.g. stripping extraneous slashes
 like C<foo//bar> into C<foo/bar>.
 
 What's the difference between this schema and C<dirname>? The default completion
-rule. This schema's completion by default only includes files and not
-directories.
+rule. C<dirname>'s completion only includes directories and not files.
 
 =head1 HOMEPAGE
 
