@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-08-19'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem path name',
@@ -24,7 +24,7 @@ like `foo//bar` into `foo/bar`.
 
 What's the difference between this schema and `filename` and `dirname`? The
 default completion rule. This schema's completion by default includes
-files as well as directories.
+files as well as directories, while `dirname`'s only include directories.
 
 _
     min_len => 1,
@@ -58,7 +58,7 @@ Sah::Schema::pathname - Filesystem path name
 
 =head1 VERSION
 
-This document describes version 0.019 of Sah::Schema::pathname (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.020 of Sah::Schema::pathname (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
 
 =head1 SYNOPSIS
 
@@ -214,7 +214,7 @@ like C<foo//bar> into C<foo/bar>.
 
 What's the difference between this schema and C<filename> and C<dirname>? The
 default completion rule. This schema's completion by default includes
-files as well as directories.
+files as well as directories, while C<dirname>'s only include directories.
 
 =head1 HOMEPAGE
 
