@@ -5,10 +5,16 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-08-19'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 our $schema = ["pathname" => {
     summary => 'Path name, must not already exist on filesystem',
+    description => <<'MARKDOWN',
+
+This is like the `pathname` schema but with an extra check that the path must
+not already exist.
+
+MARKDOWN
     prefilters => [
         'Path::check_path_not_exists',
     ],
@@ -29,7 +35,7 @@ Sah::Schema::pathname::not_exists - Path name, must not already exist on filesys
 
 =head1 VERSION
 
-This document describes version 0.019 of Sah::Schema::pathname::not_exists (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.020 of Sah::Schema::pathname::not_exists (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
 
 =head1 SYNOPSIS
 
@@ -146,6 +152,11 @@ L<Type::Tiny> as well as L<Type::FromSah>):
  use My::Types qw(PathnameNotExists);
  PathnameNotExists->assert_valid($data);
 
+=head1 DESCRIPTION
+
+This is like the C<pathname> schema but with an extra check that the path must
+not already exist.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Path>.
