@@ -5,10 +5,17 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-08-19'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem path name on a Unix system',
+    description => <<'MARKDOWN',
+
+This is like the `pathname` schema but with extra checks relevant to the Unix,
+(e.g. a path element cannot be longer than 255 characters) and prefilters (e.g.
+multipile consecutive slashes `//` will be normalized into a single one `/`).
+
+MARKDOWN
     match => '\A(?:/|/?(?:[^/\0]{1,255})(?:/[^/\0]{1,255})*)\z',
     'x.completion' => ['filename'],
     prefilters => [
@@ -42,7 +49,7 @@ Sah::Schema::pathname::unix - Filesystem path name on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.019 of Sah::Schema::pathname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.020 of Sah::Schema::pathname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
 
 =head1 SYNOPSIS
 
@@ -76,7 +83,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "/";
+ $data = "foo//bar";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -91,8 +98,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "/";
- my $res = $validator->($data); # => ["","/"]
+ $data = "foo//bar";
+ my $res = $validator->($data); # => ["","foo/bar"]
  
  # a sample invalid data
  $data = "";
@@ -189,6 +196,12 @@ L<Type::Tiny> as well as L<Type::FromSah>):
  use My::Types qw(PathnameUnix);
  PathnameUnix->assert_valid($data);
 
+=head1 DESCRIPTION
+
+This is like the C<pathname> schema but with extra checks relevant to the Unix,
+(e.g. a path element cannot be longer than 255 characters) and prefilters (e.g.
+multipile consecutive slashes C<//> will be normalized into a single one C</>).
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Path>.
