@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-08-19'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 1;
 # ABSTRACT: Schemas related to filesystem path
@@ -22,7 +22,32 @@ Sah::Schemas::Path - Schemas related to filesystem path
 
 =head1 VERSION
 
-This document describes version 0.019 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+This document describes version 0.020 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-08-19.
+
+=head1 DESCRIPTION
+
+This distribution includes several schemas you can use if you want to accept
+filename/dirname/pathname.
+
+Some general guidelines:
+
+C<pathname> should be your first choice. But if you only want to accept
+directory name, you can use C<dirname> instead. And if you only want to accept
+file name and not directory, you can use C<filename>.
+
+C<filename>, C<dirname>, C<pathname> are basically the same; they differ in the
+completion they provide, i.e. C<dirname> offers completion of only directory
+names.
+
+Use C<filename::unix>, F<dirname::unix>, F<pathname::unix> only if you want to
+accept Unix-style path. These schemas contain additional checks that are
+specific to Unix filesystem.
+
+Use C<filename::exists>, C<dirname::exists>, C<pathname::exists> if you want to
+accept an existing path. For example in a utility/routine to rename or process
+files. On the contrary, there are C<filename::not_exists>,
+C<dirhname::not_exists>, and C<pathname::not_exists> if you want to accept
+non-existing path, e.g. in a utility/routine to create a new file.
 
 =head1 SAH SCHEMAS
 
@@ -53,14 +78,43 @@ rule. This schema's completion by default only includes directories.
 
 Directory name, must exist on filesystem.
 
+This is like the C<dirname> schema but with an extra check that the path must
+already exist.
+
+
+=item * L<dirname::not_exists|Sah::Schema::dirname::not_exists>
+
+Directory name, must not exist on filesystem.
+
+This is like the C<dirname> schema but with an extra check that the path must
+not already exist.
+
+
 =item * L<dirname::unix|Sah::Schema::dirname::unix>
 
 Filesystem directory name on a Unix system.
 
+This is like the C<dirname> schema but with extra checks relevant to the Unix,
+(e.g. a path element cannot be longer than 255 characters) and prefilters (e.g.
+multipile consecutive slashes C<//> will be normalized into a single one C</>).
+
+
 =item * L<dirname::unix::exists|Sah::Schema::dirname::unix::exists>
 
 Unix directory name, must exist on filesystem.
 
+This is like the C<dirname::unix> schema but with an extra check that the path
+must already exist.
+
+
+=item * L<dirname::unix::not_exists|Sah::Schema::dirname::unix::not_exists>
+
+Unix directory name, must exist on filesystem.
+
+This is like the C<dirname::unix> schema but with an extra check that the path
+must not already exist.
+
+
 =item * L<dirnames::exist|Sah::Schema::dirnames::exist>
 
 List of directory names, all must exist on filesystem.
@@ -81,22 +135,50 @@ longer than 255 characters) and preprocessing (e.g. stripping extraneous slashes
 like C<foo//bar> into C<foo/bar>.
 
 What's the difference between this schema and C<dirname>? The default completion
-rule. This schema's completion by default only includes files and not
-directories.
+rule. C<dirname>'s completion only includes directories and not files.
 
 
 =item * L<filename::exists|Sah::Schema::filename::exists>
 
 File name, must exist on filesystem.
 
+This is like the C<filename> schema but with an extra check that the path must
+already exist.
+
+
+=item * L<filename::not_exists|Sah::Schema::filename::not_exists>
+
+File name, must not already exist on filesystem.
+
+This is like the C<filename> schema but with an extra check that the path must
+not already exist.
+
+
 =item * L<filename::unix|Sah::Schema::filename::unix>
 
 Filesystem file name on a Unix system.
 
+This is like the C<filename> schema but with extra checks relevant to the Unix,
+(e.g. a path element cannot be longer than 255 characters) and prefilters (e.g.
+multipile consecutive slashes C<//> will be normalized into a single one C</>).
+
+
 =item * L<filename::unix::exists|Sah::Schema::filename::unix::exists>
 
 Unix file name, must exist on filesystem.
 
+This is like the C<filename::unix> schema but with an extra check that the path
+must already exist.
+
+
+=item * L<filename::unix::not_exists|Sah::Schema::filename::unix::not_exists>
+
+Unix file name, must not already exist on filesystem.
+
+This is like the C<filename::unix> schema but with an extra check that the path
+must not already exist.
+
+
 =item * L<filenames|Sah::Schema::filenames>
 
 List of filesystem file names.
@@ -125,29 +207,50 @@ like C<foo//bar> into C<foo/bar>.
 
 What's the difference between this schema and C<filename> and C<dirname>? The
 default completion rule. This schema's completion by default includes
-files as well as directories.
+files as well as directories, while C<dirname>'s only include directories.
 
 
 =item * L<pathname::exists|Sah::Schema::pathname::exists>
 
 Path name, must exist on filesystem.
 
+This is like the C<pathname> schema but with an extra check that the path must
+already exist.
+
+
 =item * L<pathname::not_exists|Sah::Schema::pathname::not_exists>
 
 Path name, must not already exist on filesystem.
 
+This is like the C<pathname> schema but with an extra check that the path must
+not already exist.
+
+
 =item * L<pathname::unix|Sah::Schema::pathname::unix>
 
 Filesystem path name on a Unix system.
 
+This is like the C<pathname> schema but with extra checks relevant to the Unix,
+(e.g. a path element cannot be longer than 255 characters) and prefilters (e.g.
+multipile consecutive slashes C<//> will be normalized into a single one C</>).
+
+
 =item * L<pathname::unix::exists|Sah::Schema::pathname::unix::exists>
 
 Unix path name, must exist on filesystem.
 
+This is like the C<pathname::unix> schema but with an extra check that the path
+must already exist.
+
+
 =item * L<pathname::unix::not_exists|Sah::Schema::pathname::unix::not_exists>
 
 Unix path name, must not already exist on filesystem.
 
+This is like the C<pathname::unix> schema but with an extra check that the path
+must not already exist.
+
+
 =item * L<pathnames|Sah::Schema::pathnames>
 
 List of filesystem path names.
